@@ -1,5 +1,6 @@
 import click
 
+import sym.flow.cli.helpers.output as cli_output
 from sym.flow.cli.helpers.global_options import GlobalOptions
 from sym.flow.cli.models import ServiceType
 
@@ -23,4 +24,4 @@ def bots_delete(options: GlobalOptions, username: str) -> None:
     }
 
     options.sym_api.delete_user(payload)
-    click.secho(f"Successfully deleted bot user {username}!", fg="green")
+    cli_output.success(f"Successfully deleted bot user {username}!")
