@@ -1,5 +1,7 @@
 import click
 
+import sym.flow.cli.helpers.output as cli_output
+
 from ...helpers.debug import do_upload_directory
 
 
@@ -8,7 +10,8 @@ from ...helpers.debug import do_upload_directory
 def upload_directory(dir: click.Path) -> None:
     """Share the contents of DIR with Sym."""
 
-    click.echo("Archiving and uploading...")
+    cli_output.info("Archiving and uploading...")
     txid = do_upload_directory(str(dir))
-    click.secho(f"Your directory was shared with Sym!", fg="green")
-    click.secho(f"Transaction ID: {txid}", fg="black", bold=True)
+
+    cli_output.success("Your directory was shared with Sym!")
+    cli_output.info(f"Transaction ID: {txid}", bold=True)
