@@ -1,5 +1,6 @@
 import click
 
+import sym.flow.cli.helpers.output as cli_output
 from sym.flow.cli.helpers.global_options import GlobalOptions
 
 from ...helpers.debug import do_upload_terraform_output
@@ -11,7 +12,7 @@ from ...helpers.debug import do_upload_terraform_output
 def upload_terraform_output(options: GlobalOptions, tf_dir: click.Path) -> None:
     """Share the output from Terraform in TF_DIR with Sym."""
 
-    click.echo("Running `terraform output` and uploading...")
+    cli_output.info("Running `terraform output` and uploading...")
     txid = do_upload_terraform_output(str(tf_dir), options)
-    click.secho(f"Your Terraform output was shared with Sym!", fg="green")
-    click.secho(f"Transaction ID: {txid}", fg="black", bold=True)
+    cli_output.success("Your Terraform output was shared with Sym!")
+    cli_output.info(f"Transaction ID: {txid}", bold=True)
