@@ -1,5 +1,6 @@
 import click
 
+import sym.flow.cli.helpers.output as cli_output
 from sym.flow.cli.helpers.global_options import GlobalOptions
 
 
@@ -20,7 +21,7 @@ def domains_list(options: GlobalOptions) -> None:
     org = options.sym_api.get_current_organization()
 
     if domains := org.domains:
-        click.echo("Your organization's configured domains:")
-        click.echo("- " + "\n- ".join(domains))
+        cli_output.info("Your organization's configured domains:")
+        cli_output.info("- " + "\n- ".join(domains))
     else:
-        click.echo("Your organization does not have any domains configured.")
+        cli_output.info("Your organization does not have any domains configured.")
