@@ -7,10 +7,10 @@ from sym.shared.cli.helpers.sym_group import SymGroup
 from sym.flow.cli.commands.bots import bots_commands
 from sym.flow.cli.commands.config import config_commands
 from sym.flow.cli.commands.debug import debug_commands
+from sym.flow.cli.commands.docs import docs
 from sym.flow.cli.commands.domains import domains_commands
 from sym.flow.cli.commands.init import init
 from sym.flow.cli.commands.login import login, logout
-from sym.flow.cli.commands.policies import policies_commands
 from sym.flow.cli.commands.resources import resources_commands
 from sym.flow.cli.commands.services import services_commands
 from sym.flow.cli.commands.status import status
@@ -29,12 +29,8 @@ from ..helpers.global_options import GlobalOptions
 from ..version import __version__
 
 
-@click.group(
-    name="symflow", cls=SymGroup, context_settings={"help_option_names": ["-h", "--help"]}
-)
-@click.option(
-    "--debug", is_flag=True, help="enable verbose debugging", envvar="SYM_DEBUG"
-)
+@click.group(name="symflow", cls=SymGroup, context_settings={"help_option_names": ["-h", "--help"]})
+@click.option("--debug", is_flag=True, help="enable verbose debugging", envvar="SYM_DEBUG")
 @click.option(
     "--api-url",
     default=DEFAULT_API_URL,
@@ -76,8 +72,8 @@ symflow.add_command(services_commands)
 symflow.add_command(users_commands)
 symflow.add_command(debug_commands)
 symflow.add_command(config_commands)
-symflow.add_command(policies_commands)
 symflow.add_command(tokens_commands)
 symflow.add_command(bots_commands)
 symflow.add_command(resources_commands)
 symflow.add_command(domains_commands)
+symflow.add_command(docs)
