@@ -1,5 +1,6 @@
 import click
 
+import sym.flow.cli.helpers.output as cli_output
 from sym.flow.cli.helpers.global_options import GlobalOptions
 from sym.flow.cli.models import ServiceType
 from sym.flow.cli.models.service import BaseService
@@ -29,4 +30,4 @@ def users_delete(options: GlobalOptions, email: str) -> None:
     }
 
     options.sym_api.delete_user(payload)
-    click.secho(f"Successfully deleted user {email}!")
+    cli_output.success(f"Successfully deleted user {email}!")
