@@ -1,6 +1,7 @@
 import click
 from tabulate import tabulate
 
+import sym.flow.cli.helpers.output as cli_output
 from sym.flow.cli.helpers.api import SymAPI
 from sym.flow.cli.helpers.global_options import GlobalOptions
 from sym.flow.cli.helpers.users import UserUpdateSet
@@ -26,9 +27,9 @@ def users_list_identities(options: GlobalOptions, output_file: str) -> None:
     user_data = get_user_data(options.sym_api)
     if output_file:
         user_data.write_to_csv(output_file)
-        click.echo(f"Saved {len(user_data.users)} users to {output_file}.")
+        cli_output.info(f"Saved {len(user_data.users)} users to {output_file}.")
     else:
-        click.echo(tabulate_user_data(user_data))
+        cli_output.info(tabulate_user_data(user_data))
 
 
 def tabulate_user_data(user_data: UserUpdateSet) -> str:
