@@ -2,6 +2,7 @@ from typing import Optional
 
 import click
 
+import sym.flow.cli.helpers.output as cli_output
 from sym.flow.cli.helpers.global_options import GlobalOptions
 from sym.flow.cli.helpers.utils import get_or_prompt
 
@@ -28,4 +29,4 @@ def set_role(options: GlobalOptions, email: str, role: Optional[str] = None) ->
     role = get_or_prompt(role, "Which role?", ["admin", "member", "guest"])
     api.set_user_role(user.id, role)
 
-    click.secho(f"Success! {email} now has the role '{role}'.", fg="green")
+    cli_output.success(f"Success! {email} now has the role '{role}'.")
