@@ -9,6 +9,7 @@ from sym.flow.cli.commands.users.list_identities import users_list_identities
 from sym.flow.cli.commands.users.set_role import set_role
 from sym.flow.cli.commands.users.update import users_update
 from sym.flow.cli.commands.users.update_identity import update_user_identity
+from sym.flow.cli.commands.users.update_name import update_name
 from sym.flow.cli.helpers.global_options import GlobalOptions
 
 
@@ -22,7 +23,8 @@ users.add_command(users_create)
 users.add_command(users_list)
 users.add_command(users_list_identities)
 users.add_command(users_update)
-users.add_command(users_delete)
+users.add_command(update_name)
 users.add_command(update_user_identity)
+users.add_command(users_delete)
 users.add_command(delete_user_identity)
 users.add_command(set_role)
