@@ -23,9 +23,7 @@ from sym.flow.cli.models.user_type import UserType
 
 class SymAPI:
     def __init__(self, url: str, access_token: Optional[str] = None):
-        self.rest = SymRESTClient(
-            url=url, access_token=access_token or Config.get_access_token()
-        )
+        self.rest = SymRESTClient(url=url, access_token=access_token or Config.get_access_token())
 
     def set_access_token(self, access_token: str):
         self.rest.access_token = access_token
@@ -55,9 +53,7 @@ class SymAPI:
         """Returns True if the User's current credentials are valid as determined by the Sym API, False otherwise
         If an email is available to validate, include it in the request,
         """
-        response = self.rest.get(
-            "auth/login", filter_dict({"email": email}), validate=False
-        )
+        response = self.rest.get("auth/login", filter_dict({"email": email}), validate=False)
         return response.status_code == 200
 
     def get_integrations(self) -> List[dict]:
@@ -121,9 +117,7 @@ class SymAPI:
             retrieve the URL as a string.
         """
 
-        return self.rest.get("services/slack/link", {"service_id": service_id}).json()[
-            "url"
-        ]
+        return self.rest.get("services/slack/link", {"service_id": service_id}).json()["url"]
 
     def uninstall_slack(self, service_id: str) -> None:
         """Make a request to the Sym API to uninstall the Slack App.
@@ -134,9 +128,7 @@ class SymAPI:
 
         self.rest.get("services/slack/uninstall", {"token": service_id}, validate=False)
 
-    def get_services(
-        self, service_types: List[str] = ServiceType.all_names()
-    ) -> List[Service]:
+    def get_services(self, service_types: List[str] = ServiceType.all_names()) -> List[Service]:
         """Retrieve services in service_types registered to the currently
         authenticated user's organization.
 
@@ -151,9 +143,7 @@ class SymAPI:
         """Retrieve a Service by the given service_type and external_id.
         Expects that the response will have exactly one Service
         """
-        response = self.rest.get(
-            "services", {"service_type": service_type, "external_id": external_id}
-        ).json()
+        response = self.rest.get("services", {"service_type": service_type, "external_id": external_id}).json()
         services = parse_obj_as(List[Service], response["services"])
         if (num_services := len(services)) != 1:
             raise SymAPIUnknownError(
@@ -164,13 +154,12 @@ class SymAPI:
 
         return services[0]
 
-    def create_service(self, service_type: ServiceType, external_id: str) -> Service:
-        """Creates a new Service for the currently authenticated user's organization"""
-        response = self.rest.post(
+    def update_service(self, service_type_name: str, external_id: str, label: str):
+        """Updates a Service from the currently authenticated user's organization"""
+        return self.rest.patch(
             "services",
-            {"service_type": service_type.type_name, "external_id": external_id},
+            {"service_type": service_type_name, "external_id": external_id, "label": label},
         ).json()
-        return Service.parse_obj(response["results"][0])
 
     def delete_service(self, service_type_name: str, external_id: str):
         """Deletes a Service from the currently authenticated user's organization"""
@@ -184,15 +173,11 @@ class SymAPI:
         if any exist, a service cannot be deleted"""
         return self.rest.get(f"service/{service_id}/references").json()["references"]
 
-    def create_token(
-        self, username: str, expiry_in_seconds: int, label: Optional[str] = None
-    ) -> str:
+    def create_token(self, username: str, expiry_in_seconds: int, label: Optional[str] = None) -> str:
         """Creates a new token in the organization for the given bot-user and expiry"""
         response = self.rest.post(
             "tokens",
-            filter_dict(
-                {"username": username, "expiry": expiry_in_seconds, "label": label}
-            ),
+            filter_dict({"username": username, "expiry": expiry_in_seconds, "label": label}),
         ).json()
 
         return response["access_token"]
