@@ -34,9 +34,15 @@ class Config(ConfigBase[ConfigSchema]):
         config = cls.instance()
         return Organization(slug=config["org"], client_id=config["client_id"])
 
+    @classmethod
+    def set_org(cls, org: Organization):
+        config = cls.instance()
+        config["org"] = org.slug
+        config["client_id"] = org.client_id
+
     @classmethod
     def is_logged_in(cls):
-        return "org" in cls.instance()
+        return "auth_token" in cls.instance()
 
     @classmethod
     def get_access_token(cls) -> Optional[str]:
@@ -51,16 +57,13 @@ class Config(ConfigBase[ConfigSchema]):
             return
 
         cfg = cls.instance()
-        del cfg["email"]
-        del cfg["org"]
-        del cfg["client_id"]
-        del cfg["auth_token"]
+        cfg.pop("email", None)
+        cfg.pop("auth_token", None)
 
 
 def store_login_config(email: str, org: Organization, auth_token: AuthToken) -> str:
+    Config.set_org(org)
     cfg = Config.instance()
     cfg["email"] = email
-    cfg["org"] = org.slug
-    cfg["client_id"] = org.client_id
     cfg["auth_token"] = auth_token
     return str(cfg.file)
