@@ -10,5 +10,7 @@ WRITE_ONLY_AWS_SECRET_ACCESS_KEY = "WGN1+bYys4cc0sknfYJC0PnugCJ1kDvrfgynnOsS"
 
 DROPBOX_BUCKET = "sym-dropbox-us-east-1"
 
-
 CLI_PACKAGE_NAME = "sym-flow-cli"
+
+SYM_DOCUMENTATION_URL = "https://docs.symops.com/"
+SYM_SUPPORT_EMAIL = "support@symops.com"
