@@ -1,4 +1,5 @@
 from dataclasses import dataclass
+from typing import Optional
 from urllib.parse import urlparse
 
 from sym.shared.cli.data.global_options_base import GlobalOptionsBase
@@ -10,6 +11,16 @@ from sym.flow.cli.helpers.constants import DEFAULT_API_URL, DEFAULT_AUTH_URL
 class GlobalOptions(GlobalOptionsBase):
     api_url: str = DEFAULT_API_URL
     auth_url: str = DEFAULT_AUTH_URL
+    access_token: Optional[str] = None
+
+    @property
+    def sym_api(self):
+        from sym.flow.cli.helpers.api import SymAPI
+
+        return SymAPI(self.api_url, self.access_token)
+
+    def set_access_token(self, sym_jwt):
+        self.access_token = sym_jwt.strip()
 
     def set_api_url(self, url):
         url = url.rstrip("/")
