@@ -4,13 +4,12 @@ from abc import ABC, abstractmethod
 from http.server import HTTPServer
 from typing import Optional, Tuple
 
-import click
 import pkce
 import requests
 from sym.shared.cli.errors import CliError
 
+import sym.flow.cli.helpers.output as cli_output
 from sym.flow.cli.errors import LoginError
-from sym.flow.cli.helpers.constants import DEFAULT_SCOPES
 from sym.flow.cli.helpers.global_options import GlobalOptions
 from sym.flow.cli.helpers.login.handler import make_handler
 from sym.flow.cli.models import AuthToken, Organization, parse_auth_token
@@ -72,7 +71,7 @@ class BrowserRedirectFlow(LoginFlow):
                 # If we know the problem is that the user just signed up (and therefore their email is not validated),
                 # give them a non-error message.
                 if "complete sign up" in error_message:
-                    click.secho(error_message, fg="cyan")
+                    cli_output.info(error_message)
                     return
                 else:
                     # Otherwise, raise the error message that we got from the HTTP response.
@@ -87,11 +86,8 @@ class BrowserRedirectFlow(LoginFlow):
     def gen_state(self) -> str:
         return str(uuid.uuid4())
 
-    def gen_browser_login_params(
-        self, options: GlobalOptions, org: Organization, force: bool = False
-    ) -> str:
+    def gen_browser_login_params(self, options: GlobalOptions, org: Organization, force: bool = False) -> str:
         if force or self.browser_login_params is None:
-            scopes_str = " ".join(DEFAULT_SCOPES)
             state = self.gen_state()
             code_verifier = pkce.generate_code_verifier(length=128)
             code_challenge = pkce.get_code_challenge(code_verifier)
@@ -102,7 +98,6 @@ class BrowserRedirectFlow(LoginFlow):
                     "code_challenge_method=S256",
                     f"code_challenge={code_challenge}",
                     f"redirect_uri={self.redirect_url}",
-                    f"scope={scopes_str}",
                     f"audience=https://api.symops.com",
                     f"state={state}",
                     "prompt=login",
