@@ -1,4 +1,4 @@
-from .auth import AuthToken, UserCredentials, parse_auth_token
+from .auth import AuthToken, parse_auth_token
 from .organization import Organization
 from .service import BaseService, Service
 from .service_type import ServiceType
