@@ -55,9 +55,7 @@ class ServiceType(ServiceTypeMeta, Enum):
         validator=lambda arn: arn.startswith("arn:aws:sso:::instance/"),
         help_str="Must start with 'arn:aws:sso:::instance/'",
     )
-    PAGERDUTY = ServiceTypeMeta(
-        "pagerduty", matcher="user_id", external_id_name="PagerDuty Subdomain"
-    )
+    PAGERDUTY = ServiceTypeMeta("pagerduty", matcher="user_id", external_id_name="PagerDuty Subdomain")
     AWS_IAM = ServiceTypeMeta(
         "aws_iam",
         matcher="user_arn",
@@ -65,24 +63,14 @@ class ServiceType(ServiceTypeMeta, Enum):
         validator=lambda acct_num: acct_num.isdigit() and len(acct_num) == 12,
         help_str="Must be a 12 digit account number",
     )
-    APTIBLE = ServiceTypeMeta(
-        "aptible", matcher="user_id", external_id_name="Organization ID"
-    )
+    APTIBLE = ServiceTypeMeta("aptible", matcher="user_id", external_id_name="Organization ID")
     GOOGLE = ServiceTypeMeta("google", matcher="email", external_id_name="Email Domain")
     AUTH0 = ServiceTypeMeta("auth0", matcher="idp_id", external_id_name="External ID")
     OKTA = ServiceTypeMeta("okta", matcher="user_id", external_id_name="Okta Domain")
-    ONELOGIN = ServiceTypeMeta(
-        "onelogin", matcher="user_id", external_id_name="OneLogin Domain"
-    )
-    GITHUB = ServiceTypeMeta(
-        "github", matcher="user_id", external_id_name="Github Organization Name"
-    )
-    CUSTOM = ServiceTypeMeta(
-        "custom", matcher="user_id", external_id_name="Custom Service External ID"
-    )
-    TAILSCALE = ServiceTypeMeta(
-        "tailscale", matcher="email", external_id_name="Tailnet Name"
-    )
+    ONELOGIN = ServiceTypeMeta("onelogin", matcher="user_id", external_id_name="OneLogin Domain")
+    GITHUB = ServiceTypeMeta("github", matcher="user_id", external_id_name="Github Organization Name")
+    CUSTOM = ServiceTypeMeta("custom", matcher="user_id", external_id_name="Custom Service External ID")
+    TAILSCALE = ServiceTypeMeta("tailscale", matcher="email", external_id_name="Tailnet Name")
 
 
 # Services managed by Sym, not customers
