@@ -54,9 +54,7 @@ def login_tester(click_setup):
         expected_output: List[str],
         success: bool = True,
     ):
-        with patch(
-            "sym.flow.cli.commands.login.BrowserRedirectFlow", return_value=login_flow
-        ):
+        with patch("sym.flow.cli.commands.login.BrowserRedirectFlow", return_value=login_flow):
             with click_setup() as runner:
                 result = runner.invoke(click_command, ["login", "--org-slug", org_slug])
                 print(result.output)
@@ -116,9 +114,7 @@ def test_login_invalid_token_error(_, login_flow_invalid_token_error, login_test
     return_value=(
         get_mock_response(
             404,
-            {
-                "message": f"No Organization with the slug {TEST_LOGIN_ORG_SLUG} was found."
-            },
+            {"message": f"No Organization with the slug {TEST_LOGIN_ORG_SLUG} was found."},
         )
     ),
 )
