@@ -1,4 +1,5 @@
 import json
+import re
 import uuid
 from datetime import timedelta
 from typing import Iterator, List
@@ -8,10 +9,11 @@ from uuid import UUID
 import pytest
 import requests_mock
 from pydantic import parse_obj_as
-from requests.exceptions import SSLError
+from requests.exceptions import RequestException, SSLError
 
 from sym.flow.cli.errors import (
-    NotAuthorizedError,
+    NotLoggedInError,
+    SSLConnectionError,
     SymAPIAggregateError,
     SymAPIUnauthorizedError,
     SymAPIUnknownError,
@@ -78,21 +80,6 @@ MOCK_SERVICES_DATA = {
     ]
 }
 
-MOCK_CREATE_SERVICE_DATA = {
-    "status": "success",
-    "errors": [],
-    "succeeded": 1,
-    "failed": 0,
-    "results": [
-        {
-            "id": "4df1dae0-892b-47a1-9dee-9f818b7d331b",
-            "slug": "slack",
-            "label": "Slack",
-            "external_id": "T123ABC",
-        }
-    ],
-}
-
 MOCK_SERVICE_REFERENCES_DATA = {
     "error": "false",
     "references": {
@@ -119,7 +106,7 @@ def sym_api(sandbox) -> Iterator[SymAPI]:
 
 class TestSymRESTClient:
     def test_make_headers(self, sym_rest_client, auth_token):
-        with pytest.raises(NotAuthorizedError, match="symflow login"):
+        with pytest.raises(NotLoggedInError, match="symflow login"):
             sym_rest_client.make_headers()
 
         sym_rest_client.access_token = "access"
@@ -146,9 +133,7 @@ class TestSymRESTClient:
                 "is_retryable": False,
             },
         )
-        with pytest.raises(
-            SymAPIUnauthorizedError, match=response_with_msg.data["message"]
-        ):
+        with pytest.raises(SymAPIUnauthorizedError, match=response_with_msg.data["message"]):
             sym_rest_client.handle_response(response_with_msg)
 
         response_with_error_list = get_mock_response(
@@ -161,9 +146,7 @@ class TestSymRESTClient:
                 "results": [],
             },
         )
-        with pytest.raises(
-            SymAPIAggregateError, match=response_with_error_list.data["errors"][0]
-        ):
+        with pytest.raises(SymAPIAggregateError, match=response_with_error_list.data["errors"][0]):
             sym_rest_client.handle_response(response_with_error_list)
 
         response_200 = get_mock_response(200)
@@ -177,7 +160,7 @@ class TestSymRESTClient:
         data = {"test": "hello"}
 
         # Auth is required by default, make sure if force_auth not specified
-        with pytest.raises(NotAuthorizedError, match="symflow login"):
+        with pytest.raises(NotLoggedInError, match="symflow login"):
             sym_rest_client.post("fake-endpoint", data)
 
         mock_request.assert_not_called()
@@ -208,10 +191,20 @@ class TestSymRESTClient:
         side_effect=SSLError("Boom!"),
     )
     def test_ssl_error(self, _, sym_rest_client):
-        with pytest.raises(UnexpectedError) as e:
+        with pytest.raises(
+            SSLConnectionError, match=re.escape("SSLError('Boom!'). This is usually caused by network monitoring")
+        ) as e:
             sym_rest_client.get("auth/org/lala", force_auth=False)
 
-        assert e.value.message == "An unexpected error occurred: SSLError('Boom!')"
+    @patch(
+        "requests.request",
+        side_effect=RequestException("Boom!"),
+    )
+    def test_connection_error(self, _, sym_rest_client):
+        with pytest.raises(
+            UnexpectedError, match=re.escape("An unexpected error occurred: RequestException('Boom!')")
+        ) as e:
+            sym_rest_client.get("auth/org/lala", force_auth=False)
 
 
 class TestSymAPI:
@@ -235,9 +228,7 @@ class TestSymAPI:
         ) as mock_api_get:
             assert sym_api.verify_login("test@symops.io") is False
 
-        mock_api_get.assert_called_once_with(
-            "auth/login", {"email": "test@symops.io"}, validate=False
-        )
+        mock_api_get.assert_called_once_with("auth/login", {"email": "test@symops.io"}, validate=False)
 
     @pytest.mark.parametrize("status_code", [200])
     def test_verify_login_success(self, status_code, sym_api):
@@ -246,9 +237,7 @@ class TestSymAPI:
             return_value=(get_mock_response(status_code)),
         ) as mock_api_get:
             assert sym_api.verify_login("test@symops.io") is True
-        mock_api_get.assert_called_once_with(
-            "auth/login", {"email": "test@symops.io"}, validate=False
-        )
+        mock_api_get.assert_called_once_with("auth/login", {"email": "test@symops.io"}, validate=False)
 
     @patch(
         "sym.flow.cli.helpers.api.SymRESTClient.get",
@@ -286,9 +275,7 @@ class TestSymAPI:
     )
     def test_get_services(self, mock_api_get, sym_api):
         all_services = parse_obj_as(List[Service], MOCK_SERVICES_DATA["services"])
-        expected_services = [
-            s for s in all_services if s.service_type in ServiceType.all_names()
-        ]
+        expected_services = [s for s in all_services if s.service_type in ServiceType.all_names()]
 
         data = sym_api.get_services()
         mock_api_get.assert_called_once_with("services")
@@ -296,9 +283,7 @@ class TestSymAPI:
 
     @patch(
         "sym.flow.cli.helpers.api.SymRESTClient.get",
-        return_value=(
-            get_mock_response(200, {"services": MOCK_SERVICES_DATA["services"][:1]})
-        ),
+        return_value=(get_mock_response(200, {"services": MOCK_SERVICES_DATA["services"][:1]})),
     )
     def test_get_service(self, mock_api_get, sym_api):
         expected = Service.parse_obj(MOCK_SERVICES_DATA["services"][0])
@@ -319,29 +304,23 @@ class TestSymAPI:
     )
     def test_get_service_unexpected_response(self, mock_api_get, sym_api):
         # Mock returns more than one service
-        with pytest.raises(
-            SymAPIUnknownError, match="Expected 1 service, but found 3 instead"
-        ):
+        with pytest.raises(SymAPIUnknownError, match="Expected 1 service, but found 3 instead"):
             sym_api.get_service("slack", "T123")
 
-        mock_api_get.assert_called_once_with(
-            "services", {"service_type": "slack", "external_id": "T123"}
-        )
+        mock_api_get.assert_called_once_with("services", {"service_type": "slack", "external_id": "T123"})
 
     @patch(
-        "sym.flow.cli.helpers.api.SymRESTClient.post",
-        return_value=(get_mock_response(200, data=MOCK_CREATE_SERVICE_DATA)),
+        "sym.flow.cli.helpers.api.SymRESTClient.patch",
+        return_value=(get_mock_response(200, MOCK_SERVICES_DATA)),
     )
-    def test_create_service(self, mock_api_post, sym_api):
+    def test_update_services(self, mock_api_patch, sym_api):
         service_type = ServiceType.SLACK
         external_id = "T123ABC"
-        service = sym_api.create_service(service_type, external_id)
-        mock_api_post.assert_called_once_with(
+        sym_api.update_service(service_type.type_name, external_id, "new label")
+        mock_api_patch.assert_called_once_with(
             "services",
-            {"service_type": service_type.type_name, "external_id": external_id},
+            {"service_type": service_type.type_name, "external_id": external_id, "label": "new label"},
         )
-        assert service.service_type == service_type.type_name
-        assert service.external_id == external_id
 
     @patch(
         "sym.flow.cli.helpers.api.SymRESTClient.post",
@@ -374,9 +353,7 @@ class TestSymAPI:
     )
     def test_get_slack_install_url(self, mock_api_get, sym_api):
         url = sym_api.get_slack_install_url("fake_service_id")
-        mock_api_get.assert_called_once_with(
-            "services/slack/link", {"service_id": "fake_service_id"}
-        )
+        mock_api_get.assert_called_once_with("services/slack/link", {"service_id": "fake_service_id"})
         assert url == "http://hello.sym.com"
 
     @patch(
@@ -385,9 +362,7 @@ class TestSymAPI:
     )
     def test_uninstall_slack(self, mock_api_get, sym_api):
         assert sym_api.uninstall_slack(service_id="T1234567") is None
-        mock_api_get.assert_called_once_with(
-            "services/slack/uninstall", {"token": "T1234567"}, validate=False
-        )
+        mock_api_get.assert_called_once_with("services/slack/uninstall", {"token": "T1234567"}, validate=False)
 
     def test_last_request_id(self, sym_api):
         with requests_mock.Mocker() as m:
@@ -459,9 +434,7 @@ class TestSymAPI:
             username = "bot-user"
             expiry = int(timedelta(seconds=30).total_seconds())
             data = sym_api.create_token(username, expiry)
-            mock_api.assert_called_once_with(
-                "tokens", {"username": username, "expiry": expiry}
-            )
+            mock_api.assert_called_once_with("tokens", {"username": username, "expiry": expiry})
             assert data == access_token
 
     def test_revoke_token(self, sym_api: SymAPI):
