@@ -25,7 +25,7 @@ def test_get_or_prompt_invokes_inquirer(mock_inquire, mock_prompt):
     mock_inquire.assert_has_calls([call(mock_prompt, choices=["bar", "foo"])])
 
 
-@patch("click.echo")
+@patch("sym.flow.cli.helpers.output.info")
 def test_get_or_prompt_auto_selects(mock_echo, mock_prompt):
     # value = None, but only one choice available. Auto selects
     result = get_or_prompt(value=None, prompt=mock_prompt, choices=["foo"])
